from setuptools import setup

setup(name='cmsplugin-blog-search',
      version='0.9',
      description='Searching using language facets for cmsplugin-blog.',
      author='Oyvind Saltvik',
      author_email='oyvind.saltvik@gmail.com',
      url='http://github.com/fivethreeo/cmsplugin-blog-search/',
      packages = ['cmsplugin_blog_search'],
      install_requires = ['django-cms-facetsearch']
)



from haystack import indexes, site
from cms_facetsearch.indexes import PluginIndex
from cmsplugin_blog.models import EntryTitle

class EntryTitleIndex(PluginIndex):
    title = indexes.CharField(model_attr='title')
    url = indexes.CharField(stored=True)

    def get_placeholders(self, obj, language):
        return obj.entry.placeholders.all()
        
    def prepare_translated(self, obj, language):
        data = super(EntryTitleIndex, self).prepare_translated(obj, language)
        data['url'] = obj.get_absolute_url()
        return data

site.register(EntryTitle, EntryTitleIndex)